#!/usr/bin/env python
# -*- coding: utf-8 -*-


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


def load_version():
    """Open and parse out the version number from the _version.py module.

    Inspired by http://stackoverflow.com/a/7071358
    """
    import re
    version_file = "multiaddr/_version.py"
    version_line = open(version_file).read().rstrip()
    vre = re.compile(r'__version__ = "([^"]+)"')
    matches = vre.findall(version_line)
    if matches and len(matches) > 0:
        return matches[0]
    else:
        raise RuntimeError(
            "Cannot find version string in {version_file}.".format(
                version_file=version_file))


with open('README.rst') as readme_file:
    readme = readme_file.read()


with open('HISTORY.rst') as history_file:
    history = history_file.read()


version = load_version()

setup(
    name='multiaddr',
    version=version,
    description="Python implementation of jbenet's multiaddr",
    long_description=readme + '\n\n' + history,
    author="Steven Buss",
    author_email='steven.buss@gmail.com',
    url='https://github.com/sbuss/multiaddr',
    download_url=(
        'https://github.com/sbuss/multiaddr/tarball/%s' % version),
    packages=[
        'multiaddr',
    ],
    package_dir={'multiaddr': 'multiaddr'},
    include_package_data=True,
    license='MIT License',
    zip_safe=False,
    keywords='multiaddr',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    setup_requires=[
        'pytest-runner',
    ],
    install_requires=[
        'varint',
        'six',
        'base58',
        'netaddr',
    ],
    test_suite='tests',
    tests_require=[
        'pytest',
    ],
)
